package auth

import (
	"github.com/gin-gonic/gin"
	"net/http"
	model_res "sghgogs.com/micro/shopping-service-client/domain/model/response"
	"sghgogs.com/micro/shopping-service-client/response"
	res "sghgogs.com/micro/shopping-service-client/response"
	"sghgogs.com/micro/shopping-service-client/utils"
	pb "sghgogs.com/micro/shopping-service-service/proto"
)

// GetProfile
// @summary 获取个人信息
// @Tags Auth
// @Accept json
// @Produce json
// @Param Authorization header string true "Bearer 用户令牌"
// @Success 200 {object} response.ApiResponse{data=model_res.User} "成功"
// @Failure 400 {object} response.ApiResponse "请求错误"
// @Failure 500 {object} response.ApiResponse "内部错误"
// @Router /admin/v1/api/profile [get]
func (svc *Auth) GetProfile(c *gin.Context) {
	var _ model_res.User
	ctx, _ := utils.CreateContextWithToken(c, svc.Namespace, "ShoppingAuthService.Profile")
	profile, err := svc.Service.Profile(ctx, &pb.ProfileRequest{})
	if err != nil {
		code, mgs := response.MicroErrorRequest(err)
		c.JSON(http.StatusBadRequest, response.ErrorResponse(code, mgs))
		return
	}
	c.JSON(http.StatusOK, res.SuccessResponse(svc.getProfileRes(profile.Data)))
}
