package category

import (
	"github.com/gin-gonic/gin"
	"net/http"
	res "sghgogs.com/micro/shopping-service-client/response"
	"sghgogs.com/micro/shopping-service-client/utils"
	pb "sghgogs.com/micro/shopping-service-service/proto"
	"strconv"
)

// DeleteCategory
// @summary 删除
// @Tags 分类管理
// @Accept json
// @Produce json
// @Param Authorization header string true "Bearer 用户令牌"
// @Param    id   path      int  true  "category ID"
// @Success 200 {object} response.ApiResponse "成功"
// @Failure 400 {object} response.ApiResponse "请求错误"
// @Failure 500 {object} response.ApiResponse "内部错误"
// @Router /admin/v1/api/category/{category_id} [delete]
func (svc *Category) DeleteCategory(c *gin.Context) {
	categoryID, err := strconv.ParseInt(c.Param("category_id"), 10, 64)
	if err != nil || categoryID <= 0 {
		c.JSON(http.StatusBadRequest, res.ErrorResponse(http.StatusBadRequest, "Invalid categoryID"))
		return
	}
	ctx, _ := utils.CreateContextWithToken(c, svc.Namespace, "ShoppingRoleService.DeleteRole")
	_, err = svc.Service.DeleteCategory(ctx, &pb.DeleteCategoryRequest{
		CategoryId: categoryID,
	})
	if err != nil {
		code, mgs := res.MicroErrorRequest(err)
		c.JSON(code, res.ErrorResponse(code, mgs))
		return
	}
	c.JSON(http.StatusOK, res.SuccessResponse(nil))
}
