package product

import (
	"github.com/gin-gonic/gin"
	"net/http"
	res "sghgogs.com/micro/shopping-service-client/response"
	"sghgogs.com/micro/shopping-service-client/utils"
	pb "sghgogs.com/micro/shopping-service-service/proto"
	"strconv"
)

// DeleteProduct
// @summary 删除
// @Tags 角色管理 Roles
// @Accept json
// @Produce json
// @Param Authorization header string true "Bearer 用户令牌"
// @Param    id   path      int  true  "product ID"
// @Success 200 {object} response.ApiResponse "成功"
// @Failure 400 {object} response.ApiResponse "请求错误"
// @Failure 500 {object} response.ApiResponse "内部错误"
// @Router /admin/v1/api/product/{product_id} [delete]
func (svc *Product) DeleteProduct(c *gin.Context) {
	productID, err := strconv.ParseInt(c.Param("product_id"), 10, 64)
	if err != nil || productID <= 0 {
		c.JSON(http.StatusBadRequest, res.ErrorResponse(http.StatusBadRequest, "Invalid productID"))
		return
	}
	ctx, _ := utils.CreateContextWithToken(c, svc.Namespace, "ShoppingProductService.DeleteProduct")
	_, err = svc.Service.DeleteProduct(ctx, &pb.DeleteProductRequest{
		ProductId: productID,
	})
	if err != nil {
		code, mgs := res.MicroErrorRequest(err)
		c.JSON(code, res.ErrorResponse(code, mgs))
		return
	}
	c.JSON(http.StatusOK, res.SuccessResponse(nil))
}
