package upload

import (
	"fmt"
	"github.com/gin-gonic/gin"
	"net/http"
	"os"
	"sghgogs.com/micro/common"
	res "sghgogs.com/micro/shopping-service-client/response"
	"sghgogs.com/micro/shopping-service-client/utils/miniohelper"
	"strconv"
)

type Upload struct {
	Service   miniohelper.MinioClient
	Namespace string
}

type FileAvatar struct {
	Filename string `json:"filename"` // 文件名称
}

// UploadUserAvatar
// @summary 上传文件
// @Tags file
// @Accept multipart/form-data
// @Param file formData file true "file"
// @Param Authorization header string true "Bearer 用户令牌"
// @Success 200 {object} response.ApiResponse{data=FileAvatar} "成功"
// @Failure 400 {object} response.ApiResponse "请求错误"
// @Failure 500 {object} response.ApiResponse "内部错误"
// @Router /admin/v1/api/upload/file/{file_type} [post]
func (svc *Upload) UploadUserAvatar(c *gin.Context) {
	fileType, err := strconv.ParseInt(c.Param("file_type"), 10, 64)
	if err != nil || fileType <= 0 {
		c.JSON(http.StatusBadRequest, res.ErrorResponse(http.StatusBadRequest, common.ErrorMessage[common.TypeRequiredError]))
		return
	}
	file, err := c.FormFile("file")
	if err != nil {
		c.JSON(http.StatusBadRequest, res.ErrorResponse(http.StatusBadRequest, "Bad Request"))
		return
	}
	// Save the file to a temporary location on the server
	filePath := "uploads/" + file.Filename

	if err = c.SaveUploadedFile(file, filePath); err != nil {
		c.JSON(http.StatusInternalServerError, res.ErrorResponse(http.StatusInternalServerError, "Internal Server Error"))
		return
	}
	filename := "/file"
	if fileType == 1 {
		filename = fmt.Sprintf("/%v/user-avatar", svc.Namespace)
	}
	if fileType == 2 {
		filename = fmt.Sprintf("/%v/admin-user-avatar", svc.Namespace)
	}
	if fileType == 3 {
		filename = fmt.Sprintf("/%v/product", svc.Namespace)
	}
	uploadFile, err := svc.Service.UploadFile("test", filename, file.Filename, filePath)
	if err != nil {
		c.JSON(http.StatusInternalServerError, res.ErrorResponse(http.StatusInternalServerError, err.Error()))
		return
	}
	// 删除本地文件
	err = os.Remove(filePath)
	if err != nil {
		// 处理文件删除失败的情况
		c.JSON(http.StatusInternalServerError, res.ErrorResponse(http.StatusInternalServerError, err.Error()))
		return
	}

	c.JSON(http.StatusOK, res.SuccessResponse(FileAvatar{
		Filename: uploadFile,
	}))
}
