package user

import (
	"github.com/gin-gonic/gin"
	"net/http"
	"sghgogs.com/micro/common"
	res "sghgogs.com/micro/shopping-service-client/response"
	"sghgogs.com/micro/shopping-service-client/utils"
	pb "sghgogs.com/micro/shopping-service-service/proto"
	"strconv"
)

// DeleteUser
// @summary 删除
// @Tags 用户管理
// @Accept json
// @Produce json
// @Param Authorization header string true "Bearer 用户令牌"
// @Param    id   path      int  true  "user ID"
// @Success 200 {object} response.ApiResponse "成功"
// @Failure 400 {object} response.ApiResponse "请求错误"
// @Failure 500 {object} response.ApiResponse "内部错误"
// @Router /admin/v1/api/user/{user_id} [delete]
func (svc *User) DeleteUser(c *gin.Context) {
	userID, err := strconv.ParseInt(c.Param("user_id"), 10, 64)
	if err != nil || userID <= 0 {
		c.JSON(http.StatusBadRequest, res.ErrorResponse(http.StatusBadRequest, common.ErrorMessage[common.InvalidUserID]))
		return
	}
	ctx, _ := utils.CreateContextWithToken(c, svc.Namespace, "ShoppingUserService.DeleteUser")
	_, err = svc.Service.DeleteUser(ctx, &pb.DeleteUserRequest{UserId: userID})
	if err != nil {
		code, mgs := res.MicroErrorRequest(err)
		c.JSON(code, res.ErrorResponse(code, mgs))
		return
	}
	c.JSON(http.StatusOK, res.SuccessResponse(nil))
}
