package base

import (
	"github.com/pkg/errors"
	pb "sghgogs.com/micro/shopping-service-service/proto"
)

type ListMapItem struct {
	Key   string `json:"key"`
	Value string `json:"value"`
}

type Status string

const (
	ToggleEnabled  Status = "ENABLED"
	ToggleDisabled Status = "DISABLED"
	ToggleDeleted  Status = "DELETED"
)

func MapStatusToEnum(status Status) (pb.StatusEnum, error) {
	switch string(status) {
	case "ENABLED":
		return pb.StatusEnum_ENABLED, nil
	case "DISABLED":
		return pb.StatusEnum_DISABLED, nil
	case "DELETED":
		return pb.StatusEnum_DELETED, nil
	default:
		return pb.StatusEnum_UNKNOWN, errors.New("invalid status value")
	}
}
func MapEnumToStatus(status pb.StatusEnum) (Status, error) {
	switch status {
	case pb.StatusEnum_ENABLED:
		return ToggleEnabled, nil
	case pb.StatusEnum_DISABLED:
		return ToggleDisabled, nil
	case pb.StatusEnum_DELETED:
		return ToggleDeleted, nil
	default:
		return "UNKNOWN", errors.New("invalid status value")
	}
}

type PaymentMethodEnum int

const (
	PAYMENT_UNKNOWN PaymentMethodEnum = 0
	ALIPAY          PaymentMethodEnum = 1
	WECHAT_PAY      PaymentMethodEnum = 2
	BANK_ACCOUNT    PaymentMethodEnum = 3
	CREDIT_CARD     PaymentMethodEnum = 4
	VIRTUAL_WALLET  PaymentMethodEnum = 5
	OFFLINE_PAYMENT PaymentMethodEnum = 6
	USER_ACCOUNT    PaymentMethodEnum = 7
)

func MapEnumToPaymentMethod(method pb.PaymentMethodEnum) (PaymentMethodEnum, error) {
	switch method {
	case pb.PaymentMethodEnum_ALIPAY:
		return ALIPAY, nil
	case pb.PaymentMethodEnum_WECHAT_PAY:
		return WECHAT_PAY, nil
	case pb.PaymentMethodEnum_BANK_ACCOUNT:
		return BANK_ACCOUNT, nil
	case pb.PaymentMethodEnum_CREDIT_CARD:
		return CREDIT_CARD, nil
	case pb.PaymentMethodEnum_VIRTUAL_WALLET:
		return VIRTUAL_WALLET, nil
	case pb.PaymentMethodEnum_OFFLINE_PAYMENT:
		return OFFLINE_PAYMENT, nil
	case pb.PaymentMethodEnum_USER_ACCOUNT:
		return USER_ACCOUNT, nil
	default:
		return PAYMENT_UNKNOWN, errors.New("invalid status value")
	}
}

type PaymentStatusEnum int

const (
	PAYMENT_STATUS_UNKNOWN      PaymentStatusEnum = 0
	PAYMENT_PENDING             PaymentStatusEnum = 1
	PAYMENT_PROCESSING          PaymentStatusEnum = 2
	PAYMENT_PAID                PaymentStatusEnum = 3
	PAYMENT_FAILED              PaymentStatusEnum = 4
	PAYMENT_CANCELED            PaymentStatusEnum = 5
	PAYMENT_REFUNDING           PaymentStatusEnum = 6
	PAYMENT_REFUNDED            PaymentStatusEnum = 7
	PAYMENT_PARTIALLY_REFUNDING PaymentStatusEnum = 8
	PAYMENT_PARTIALLY_REFUNDED  PaymentStatusEnum = 9
)

func MapEnumToPaymentStatus(enum pb.PaymentStatusEnum) (PaymentStatusEnum, error) {
	switch enum {
	case pb.PaymentStatusEnum_PAYMENT_PENDING:
		return PAYMENT_PENDING, nil
	case pb.PaymentStatusEnum_PAYMENT_PROCESSING:
		return PAYMENT_PROCESSING, nil
	case pb.PaymentStatusEnum_PAYMENT_PAID:
		return PAYMENT_PAID, nil
	case pb.PaymentStatusEnum_PAYMENT_FAILED:
		return PAYMENT_FAILED, nil
	case pb.PaymentStatusEnum_PAYMENT_CANCELED:
		return PAYMENT_CANCELED, nil
	case pb.PaymentStatusEnum_PAYMENT_REFUNDING:
		return PAYMENT_REFUNDING, nil
	case pb.PaymentStatusEnum_PAYMENT_REFUNDED:
		return PAYMENT_REFUNDED, nil
	case pb.PaymentStatusEnum_PAYMENT_PARTIALLY_REFUNDING:
		return PAYMENT_PARTIALLY_REFUNDING, nil
	case pb.PaymentStatusEnum_PAYMENT_PARTIALLY_REFUNDED:
		return PAYMENT_PARTIALLY_REFUNDED, nil
	default:
		return PAYMENT_STATUS_UNKNOWN, errors.New("invalid status value")
	}
}
