package adminuser

import (
	"github.com/gin-gonic/gin"
	"go-micro.dev/v4/client"
	"sghgogs.com/micro/shopping-service-client/api/adminuser"
	"sghgogs.com/micro/shopping-service-client/utils"
	"sghgogs.com/micro/shopping-service-client/utils/baseservice"
	pb "sghgogs.com/micro/shopping-service-service/proto"
)

type AdminUser struct {
	*baseservice.BaseService
}

func NewAdminUserRouter(namespace string, client client.Client) *AdminUser {
	return &AdminUser{
		BaseService: &baseservice.BaseService{
			Namespace: namespace,
			Client:    client,
		},
	}
}
func (svc *AdminUser) RegisterRoutes(r *gin.Engine) {
	api := adminuser.AdminUser{}
	api.Namespace = svc.Namespace
	api.Service = pb.NewShoppingAdminUserService(svc.Namespace, svc.Client)
	svc.registerUserAdminRoutes(r, "/admin/v1/api/manager", &api)
}

func (svc *AdminUser) registerUserAdminRoutes(r *gin.Engine, path string, api *adminuser.AdminUser) {
	v1 := r.Group(path).Use(utils.TokenAuthMiddleware())
	{
		v1.GET("/users", api.GetAdminUserList)
		v1.GET("/all_users", api.GetAllAdminUser)
		v1.GET("/user/:user_id", api.GetAdminUser)
		v1.POST("/user", api.CreateAdminUser)
		v1.DELETE("/user/:user_id", api.DeleteAdminUser)
		v1.PUT("/user/:user_id/toggle", api.ToggleAdminUser)
		v1.PUT("/user/:user_id", api.UpdateAdminUser)
	}
}
