package permission

import (
	"github.com/gin-gonic/gin"
	"go-micro.dev/v4/client"
	"sghgogs.com/micro/shopping-service-client/api/permission"
	"sghgogs.com/micro/shopping-service-client/utils"
	"sghgogs.com/micro/shopping-service-client/utils/baseservice"
	pb "sghgogs.com/micro/shopping-service-service/proto"
)

type Permission struct {
	*baseservice.BaseService
}

func NewPermissionRouter(namespace string, client client.Client) *Permission {
	return &Permission{
		BaseService: &baseservice.BaseService{
			Namespace: namespace,
			Client:    client,
		},
	}
}
func (svc *Permission) RegisterRoutes(r *gin.Engine) {
	api := permission.Permission{}
	api.Namespace = svc.Namespace
	api.Service = pb.NewShoppingPermissionService(svc.Namespace, svc.Client)
	svc.registerPermissionRoutes(r, "/admin/v1/api", &api)
}
func (svc *Permission) registerPermissionRoutes(r *gin.Engine, path string, api *permission.Permission) {
	v1 := r.Group(path).Use(utils.TokenAuthMiddleware())
	{
		v1.GET("/permissions", api.GetPermissionList)
		v1.GET("/permission/:permission_id", api.GetPermission)
		v1.POST("/permission", api.CreatePermission)
		v1.PUT("/permission/:permission_id", api.UpdatePermission)
		v1.PUT("/permission/:permission_id/toggle", api.TogglePermission)
		v1.DELETE("/permission/:permission_id", api.DeletePermission)
	}
}
