package role

import (
	"github.com/gin-gonic/gin"
	"go-micro.dev/v4/client"
	"sghgogs.com/micro/shopping-service-client/api/role"
	"sghgogs.com/micro/shopping-service-client/utils"
	"sghgogs.com/micro/shopping-service-client/utils/baseservice"
	pb "sghgogs.com/micro/shopping-service-service/proto"
)

type Role struct {
	*baseservice.BaseService
}

func NewRoleRouter(namespace string, client client.Client) *Role {
	return &Role{
		BaseService: &baseservice.BaseService{
			Namespace: namespace,
			Client:    client,
		},
	}
}
func (svc *Role) RegisterRoutes(r *gin.Engine) {
	api := role.Role{}
	api.Namespace = svc.Namespace
	api.Service = pb.NewShoppingRoleService(svc.Namespace, svc.Client)
	svc.registerRoleRoutes(r, "/admin/v1/api", &api)
}
func (svc *Role) registerRoleRoutes(r *gin.Engine, path string, api *role.Role) {
	v1 := r.Group(path).Use(utils.TokenAuthMiddleware())
	{
		v1.GET("/roles", api.GetRoleList)
		v1.GET("/all_roles", api.GetAllRoles)
		v1.GET("/role/:role_id", api.GetRole)
		v1.POST("/role", api.CreateRole)
		v1.PUT("/role/:role_id", api.UpdateRole)
		v1.DELETE("/role/:role_id", api.DeleteRole)
		v1.PUT("/role/:role_id/toggle", api.ToggleRole)
	}
}

// all_roles
